@@ -5,9 +5,11 @@ function( params,        # parameters over which to calculate
 {
   
 # Turn params into a matrix:
-  if( is.null( dim(params) ) )           # if it's a vector ... -->
-    params <- t(params)                  # ... --> turn it into a matrix
-    
+  params <- rbind(params)
+  
+# Then find the number of people:
+  N <- length(theta)
+     
 #~~~~~~~~~~~~~~~~~#
 # Argument Checks #
 #~~~~~~~~~~~~~~~~~#
@@ -19,18 +21,16 @@ function( params,        # parameters over which to calculate
 # KL Information #
 #~~~~~~~~~~~~~~~~#
 
-  if( length(theta) == 1 & length(delta) == 1 ){
+  if( N == 1 ){
     p0 <- p.brm(params, theta - delta); p1 <- p.brm(params, theta + delta)
     q0 <- q.brm(params, theta - delta); q1 <- q.brm(params, theta + delta)
-  }
-  
-  else{
+  } else{
     p0 <- apply(params, MARGIN = 1, FUN = p.brm, theta = theta - delta)
     p1 <- apply(params, MARGIN = 1, FUN = p.brm, theta = theta + delta)
  
     q0 <- apply(params, MARGIN = 1, FUN = q.brm, theta = theta - delta)
     q1 <- apply(params, MARGIN = 1, FUN = q.brm, theta = theta + delta)
-  }
+  } # END ifelse STATEMENT
   
 # To prevent computation problems, work with logs and not probabilities:
   info <- p1 * ( log(p1) - log(p0) ) + q1 * ( log(q1) - log(q0) )
@@ -38,11 +38,17 @@ function( params,        # parameters over which to calculate
 # If theta is a scalar, item information is a vector and test information is a scalar
 # If theta is a vector, item information is a matrix and test information is a vector
   
-  i.info <- { if( length(theta) == 1 )   info
-              else                     t(info) }
-                  
-  t.info <- { if( length(theta) == 1 ) sum(info)
-              else                     apply(i.info, MARGIN = 2, FUN = sum) }
+  if( N == 1 ){
+  
+    i.info <- info
+    t.info <- sum(info)
+    
+  } else{
+  	
+    i.info <- t(info)
+    t.info <- colSums(i.info)
+    
+  } # END ifelse STATEMENT
                   
                   
   return( list(item = i.info, test = t.info) )
